@@ -1,13 +1,31 @@
+MONOMINO = [(0, 0)]
+
+DOMINO = [(0, 0), (0, 1)]
+
+TROMINOS = {
+    'Straight': [(0, 0), (0, 1), (0, 2)],
+    'Right':    [(0, 0), (0, 1), (1, 1)]
+}
+
+STRAIGHT_TROMINO = TROMINOS['Straight']
+RIGHT_TROMINO = TROMINOS['Right']
+
 TETROMINOS = {
     'Square': [(0, 0), (0, 1), (1, 0), (1, 1)],
-    'T':      [(0, 0), (0, 1), (1, 0), (2, 0)],
+    'T':      [(0, 0), (1, 1), (1, 0), (2, 0)],
     'S':      [(0, 0), (1, 0), (1, 1), (2, 1)],
-    'Z':      [(0, 1), (1, 0), (1, 1), (2, 0)],
     'Line':   [(0, 0), (1, 0), (2, 0), (3, 0)],
     'J':      [(0, 0), (1, 0), (1, 1), (1, 2)],
-    'L':      [(0, 0), (0, 1), (0, 2), (1, 0)]
 }
 
+ALL_TETROMINOS = list(TETROMINOS.values())
+
+ONESIDED_TETROMINOS = TETROMINOS
+ONESIDED_TETROMINOS.update({
+    'Z':      [(0, 1), (1, 0), (1, 1), (2, 0)],
+    'L':      [(0, 0), (0, 1), (0, 2), (1, 0)]
+})
+
 PENTOMINOS = {
     'F': [(0, 1), (1, 0), (1, 1), (2, 1), (2, 2)],
     'I': [(0, 0), (0, 1), (0, 2), (0, 3), (0, 4)],
@@ -22,3 +40,5 @@ PENTOMINOS = {
     'Y': [(0, 2), (1, 0), (1, 1), (1, 2), (1, 3)],
     'Z': [(0, 2), (1, 0), (1, 1), (1, 2), (2, 0)]
 }
+
+ALL_PENTOMINOS = list(PENTOMINOS.values())
